@@ -4,7 +4,7 @@
 #
 # @author: Eric Lapouyade
 
-__version__ = '0.2.2'
+__version__ = '0.2.3'
 __author__ = 'Eric Lapouyade'
 __copyright__ = 'Copyright 2015, python-textops project'
 __credits__ = ['Eric Lapouyade']
@@ -26,6 +26,7 @@ logger.addHandler(NullHandler())
 
 from base import TextOp, WrapOp, WrapOpIter, WrapOpStr, add_textop, add_textop_iter, \
                  StrExt, UnicodeExt, ListExt, DictExt, NoAttrDict, NoAttr, DefaultList, \
-                 DefaultDict, string_formatter, vformat, dformat, eformat, activate_debug, pp
+                 DefaultDict, string_formatter, dictmerge, vformat, dformat, eformat, \
+                 stru, activate_debug, pp
 import ops
 from ops import *
