@@ -479,6 +479,13 @@ def extend_type_gen(obj):
     for i in obj:
         yield extend_type(i)
 
+def stru(text):
+    if isinstance(text, unicode):
+        text = text.encode('utf-8','replace')
+    else:
+        text = str(text)
+    return text
+
 def set_debug(flag):
     """ Change debug level
 
@@ -610,6 +617,8 @@ class DebugText(object):
         return out
 
 def get_attribute_or_textop(obj,name):
+    if name[:2]=='__':
+        return object.__getattribute__(obj,name)
     op_cls = getattr(textops.ops,name,None)
     if op_cls and isinstance(op_cls,type) and issubclass(op_cls,TextOp):
         def fn(*args,**kwargs):
@@ -631,7 +640,7 @@ def get_attribute_or_textop(obj,name):
             if isinstance(obj,DictExt):
                 return NoAttr
             def fn(*args,**kwargs):
-                return map(lambda s:getattr(str, name)(s,*args,**kwargs),obj)
+                return map(lambda s:getattr(str if isinstance(s,str) else unicode, name)(s,*args,**kwargs),obj)
 
     if not callable(fn):
         return fn
@@ -857,12 +866,12 @@ class DictExt(NoAttrDict):
 
         Examples:
 
-        >>> s = '''soft:textops
-        ... count:32591'''
-        >>> s | parse_indented()
-        {'count': '32591', 'soft': 'textops'}
-        >>> s | parse_indented().amend(date='2015-11-19')
-        {'count': '32591', 'date': '2015-11-19', 'soft': 'textops'}
+            >>> s = '''soft:textops
+            ... count:32591'''
+            >>> s | parse_indented()
+            {'count': '32591', 'soft': 'textops'}
+            >>> s | parse_indented().amend(date='2015-11-19')
+            {'count': '32591', 'date': '2015-11-19', 'soft': 'textops'}
         """
         return DictExt(self,*args, **kwargs)
     def render(self,format_string,defvalue='-'):
@@ -876,11 +885,11 @@ class DictExt(NoAttrDict):
 
         Examples:
 
-        >>> d = DictExt({'count': '32591', 'date': '2015-11-19', 'soft': 'textops'})
-        >>> d.render('On {date}, "{soft}" has been downloaded {count} times')
-        'On 2015-11-19, "textops" has been downloaded 32591 times'
-        >>> d.render('On {date}, "{not_in_dict}" has been downloaded {count} times','?')
-        'On 2015-11-19, "?" has been downloaded 32591 times'
+            >>> d = DictExt({'count': '32591', 'date': '2015-11-19', 'soft': 'textops'})
+            >>> d.render('On {date}, "{soft}" has been downloaded {count} times')
+            'On 2015-11-19, "textops" has been downloaded 32591 times'
+            >>> d.render('On {date}, "{not_in_dict}" has been downloaded {count} times','?')
+            'On 2015-11-19, "?" has been downloaded 32591 times'
         """
         return dformat(format_string,self,defvalue)
     def __getitem__(self,*args, **kwargs):
@@ -912,6 +921,29 @@ class DefaultList(list):
                 return self.defvalue(key)
             return self.defvalue
 
+def dictmerge(*dict_args):
+    """Merge as many dicts you want
+
+    Given any number of dicts, shallow copy and merge into a new dict,
+    precedence goes to key value pairs in latter dicts.
+
+    Args:
+        *dict_args (dict): List of dicts
+
+    Returns:
+        dict: a new merged dict
+
+    Examples:
+
+        >>> dictmerge({'a':1,'b':2},{'b':3,'c':4})
+        {'a': 1, 'c': 4, 'b': 3}
+
+    """
+    result = {}
+    for dictionary in dict_args:
+        result.update(dictionary)
+    return result
+
 string_formatter = string.Formatter()
 vformat = string_formatter.vformat
 
@@ -929,13 +961,13 @@ def dformat(format_str,dct,defvalue='-'):
 
     Examples:
 
-    >>> d = {'count': '32591', 'soft': 'textops'}
-    >>> dformat('{soft} : {count} dowloads',d)
-    'textops : 32591 dowloads'
-    >>> dformat('{software} : {count} dowloads',d,'N/A')
-    'N/A : 32591 dowloads'
-    >>> dformat('{software} : {count} dowloads',d,lambda k:'unknown_tag_%s' % k)
-    'unknown_tag_software : 32591 dowloads'
+        >>> d = {'count': '32591', 'soft': 'textops'}
+        >>> dformat('{soft} : {count} dowloads',d)
+        'textops : 32591 dowloads'
+        >>> dformat('{software} : {count} dowloads',d,'N/A')
+        'N/A : 32591 dowloads'
+        >>> dformat('{software} : {count} dowloads',d,lambda k:'unknown_tag_%s' % k)
+        'unknown_tag_software : 32591 dowloads'
     """
     return vformat(format_str,(),DefaultDict(defvalue,dct))
 
@@ -953,13 +985,13 @@ def eformat(format_str,lst,dct,defvalue='-'):
 
     Examples:
 
-    >>> d = {'count': '32591', 'soft': 'textops'}
-    >>> l = ['Eric','Guido']
-    >>> eformat('{0} => {soft} : {count} dowloads',l,d)
-    'Eric => textops : 32591 dowloads'
-    >>> eformat('{2} => {software} : {count} dowloads',l,d,'N/A')
-    'N/A => N/A : 32591 dowloads'
-    >>> eformat('{2} => {software} : {count} dowloads',l,d,lambda k:'unknown_tag_%s' % k)
-    'unknown_tag_2 => unknown_tag_software : 32591 dowloads'
+        >>> d = {'count': '32591', 'soft': 'textops'}
+        >>> l = ['Eric','Guido']
+        >>> eformat('{0} => {soft} : {count} dowloads',l,d)
+        'Eric => textops : 32591 dowloads'
+        >>> eformat('{2} => {software} : {count} dowloads',l,d,'N/A')
+        'N/A => N/A : 32591 dowloads'
+        >>> eformat('{2} => {software} : {count} dowloads',l,d,lambda k:'unknown_tag_%s' % k)
+        'unknown_tag_2 => unknown_tag_software : 32591 dowloads'
     """
     return vformat(format_str,DefaultList(defvalue,lst),DefaultDict(defvalue,dct))
